@@ -10,13 +10,12 @@ import warnings
 from dataclasses import dataclass
 from typing import Any, Callable, Dict, List, Optional
 
-import annofabapi.utils
 from annofabapi import AnnofabApi
 from annofabapi.exceptions import AnnofabApiException
 from annofabapi.models import (AnnotationDataHoldingType, AnnotationSpecsV1, InputData, Inspection, InspectionStatus,
                                Instruction, JobInfo, JobStatus, JobType, MyOrganization, Organization,
                                OrganizationMember, Project, ProjectMember, SupplementaryData, Task)
-from annofabapi.utils import allow_404_error
+from annofabapi.utils import _download, _log_error_response, _raise_for_status, allow_404_error, str_now
 
 logger = logging.getLogger(__name__)
 
@@ -41,7 +40,7 @@ class AnnotationSpecsRelation:
     choice_id: Dict[ChoiceKey, ChoiceKey]
 
 
-def __first_true(iterable, default=None, pred=None):
+def _first_true(iterable, default=None, pred=None):
     return next(filter(pred, iterable), default)
 
 
@@ -153,7 +152,7 @@ class Wrapper:
 
         _, response = self.api.get_annotation_archive(project_id, query_params=query_params)
         url = response.headers['Location']
-        annofabapi.utils.download(url, dest_path)
+        _download(url, dest_path)
         return url
 
     def download_full_annotation_archive(self, project_id: str, dest_path: str) -> str:
@@ -173,7 +172,7 @@ class Wrapper:
         warnings.warn("deprecated", DeprecationWarning)
         _, response = self.api.get_archive_full_with_pro_id(project_id)
         url = response.headers['Location']
-        annofabapi.utils.download(url, dest_path)
+        _download(url, dest_path)
         return url
 
     def get_all_annotation_list(self, project_id: str,
@@ -299,7 +298,8 @@ class Wrapper:
             src: コピー元のTaskFrame情報
             dest: コピー先のTaskFrame情報
             account_id: アノテーションを登録するユーザのアカウントID
-            annotation_specs_relation: アノテーション仕様間の紐付け情報
+            annotation_specs_relation: アノテーション仕様間の紐付け情報。``get_annotation_specs_relation`` メソッドで紐付け情報を取得できる。
+                Noneの場合、コピー元のアノテーション仕様のID情報（ラベルID、属性ID、選択肢ID）を変換せずに、アノテーションをコピーします。
 
         Returns:
             アノテーションのコピー実施したかどうか
@@ -344,7 +344,7 @@ class Wrapper:
         src_annotation_specs = self.api.get_annotation_specs(src_project_id)[0]
 
         if comment is None:
-            comment = f"Copied the annotation specification of project {src_project_id} on {annofabapi.utils.str_now()}"
+            comment = f"Copied the annotation specification of project {src_project_id} on {str_now()}"
 
         request_body = {
             "labels": src_annotation_specs["labels"],
@@ -371,11 +371,42 @@ class Wrapper:
         messages = choice["name"]["messages"]
         return [e["message"] for e in messages if e["lang"] == "en-US"][0]
 
+    def __get_dest_additional(self, src_additional: Dict[str, Any], dest_additionals: List[Dict[str, Any]],
+                              src_labels: List[Dict[str, Any]], dest_labels: List[Dict[str, Any]],
+                              dict_label_id: Dict[str, str]) -> Optional[Dict[str, Any]]:
+        src_additional_name_en = self.__get_additional_data_definition_name_en(src_additional)
+        for dest_additional in dest_additionals:
+            if src_additional_name_en != self.__get_additional_data_definition_name_en(dest_additional):
+                continue
+
+            dest_label_contains_dest_additional = True
+            for src_label in src_labels:
+                if src_additional["additional_data_definition_id"] in src_label["additional_data_definitions"]:
+                    dest_label_id = dict_label_id.get(src_label["label_id"])
+                    if dest_label_id is None:
+                        dest_label_contains_dest_additional = False
+                        break
+
+                    dest_label = _first_true(dest_labels, pred=lambda e, f=dest_label_id: e["label_id"] == f)
+                    if dest_label is None:
+                        dest_label_contains_dest_additional = False
+                        break
+                    if dest_additional["additional_data_definition_id"] not in dest_label[
+                            "additional_data_definitions"]:
+                        dest_label_contains_dest_additional = False
+                        break
+
+            if dest_label_contains_dest_additional:
+                return dest_additional
+
+        return None
+
     def get_annotation_specs_relation(self, src_project_id: str, dest_project_id: str) -> AnnotationSpecsRelation:
         """
-        プロジェクト間のアノテーション仕様の紐付け情報を取得する。ラベル、属性、選択肢の英語名で紐付ける。
+        プロジェクト間のアノテーション仕様の紐付け情報を取得する。
+        ラベル、属性、選択肢の英語名で紐付ける。
+        ただし、属性は、参照されるラベルが一致していることも判定する。
         紐付け先がない場合は無視する。
-        ``copy_annotation`` メソッドで利用する。
 
         Args:
             src_project_id: 紐付け元のプロジェクトID
@@ -393,17 +424,17 @@ class Wrapper:
         dict_label_id: Dict[str, str] = {}
         for src_label in src_annotation_specs["labels"]:
             src_label_name_en = self.__get_label_name_en(src_label)
-            dest_label = __first_true(dest_labels, pred=lambda e, f=src_label_name_en: self.__get_label_name_en(e) == f)
+            dest_label = _first_true(dest_labels, pred=lambda e, f=src_label_name_en: self.__get_label_name_en(e) == f)
             if dest_label is not None:
                 dict_label_id[src_label["label_id"]] = dest_label["label_id"]
 
         dict_additional_data_definition_id: Dict[str, str] = {}
         dict_choice_id: Dict[ChoiceKey, ChoiceKey] = {}
         for src_additional in src_annotation_specs["additionals"]:
-            src_additional_name_en = self.__get_additional_data_definition_name_en(src_additional)
-            dest_additional = __first_true(
-                dest_additionals,
-                pred=lambda e, f=src_additional_name_en: self.__get_additional_data_definition_name_en(e) == f)
+            dest_additional = self.__get_dest_additional(src_additional=src_additional,
+                                                         dest_additionals=dest_additionals,
+                                                         src_labels=src_annotation_specs["labels"],
+                                                         dest_labels=dest_labels, dict_label_id=dict_label_id)
             if dest_additional is None:
                 continue
 
@@ -413,8 +444,8 @@ class Wrapper:
             dest_choices = dest_additional["choices"]
             for src_choice in src_additional["choices"]:
                 src_choice_name_en = self.__get_choice_name_en(src_choice)
-                dest_choice = __first_true(dest_choices,
-                                           pred=lambda e, f=src_choice_name_en: self.__get_choice_name_en(e) == f)
+                dest_choice = _first_true(dest_choices,
+                                          pred=lambda e, f=src_choice_name_en: self.__get_choice_name_en(e) == f)
                 if dest_choice is not None:
                     dict_choice_id[ChoiceKey(src_additional["additional_data_definition_id"],
                                              src_choice["choice_id"])] = ChoiceKey(
@@ -500,8 +531,8 @@ class Wrapper:
         # アップロード
         res_put = self.api.session.put(s3_url, params=query_dict, data=data, headers={'content-type': content_type})
 
-        annofabapi.utils.log_error_response(logger, res_put)
-        annofabapi.utils.raise_for_status(res_put)
+        _log_error_response(logger, res_put)
+        _raise_for_status(res_put)
         return content["path"]
 
     def put_input_data_from_file(self, project_id: str, input_data_id: str, file_path: str,
@@ -552,10 +583,10 @@ class Wrapper:
         url = response.headers['Location']
 
         response = self.api.session.get(url)
-        annofabapi.utils.log_error_response(logger, response)
+        _log_error_response(logger, response)
 
         response.encoding = 'utf-8'
-        annofabapi.utils.raise_for_status(response)
+        _raise_for_status(response)
         content = self.api._response_to_content(response)
         return content
 
@@ -643,7 +674,7 @@ class Wrapper:
             if inspection["updated_datetime"] is None:
                 inspection["updated_datetime"] = inspection["created_datetime"]
             else:
-                inspection["updated_datetime"] = annofabapi.utils.str_now()
+                inspection["updated_datetime"] = str_now()
 
         req_inspection = [{"data": e, "_type": "Put"} for e in target_inspections]
         content = self.api.batch_update_inspections(project_id, task_id, input_data_id, req_inspection)[0]
@@ -758,7 +789,7 @@ class Wrapper:
         """
         content, _ = self.api.get_project_inputs_url(project_id)
         url = content["url"]
-        annofabapi.utils.download(url, dest_path)
+        _download(url, dest_path)
         return url
 
     def download_project_tasks_url(self, project_id: str, dest_path: str) -> str:
@@ -777,7 +808,7 @@ class Wrapper:
 
         content, _ = self.api.get_project_tasks_url(project_id)
         url = content["url"]
-        annofabapi.utils.download(url, dest_path)
+        _download(url, dest_path)
         return url
 
     def download_project_inspections_url(self, project_id: str, dest_path: str) -> str:
@@ -796,7 +827,7 @@ class Wrapper:
 
         content, _ = self.api.get_project_inspections_url(project_id)
         url = content["url"]
-        annofabapi.utils.download(url, dest_path)
+        _download(url, dest_path)
         return url
 
     def download_project_task_history_events_url(self, project_id: str, dest_path: str) -> str:
@@ -815,7 +846,7 @@ class Wrapper:
 
         content, _ = self.api.get_project_task_history_events_url(project_id)
         url = content["url"]
-        annofabapi.utils.download(url, dest_path)
+        _download(url, dest_path)
         return url
 
     #########################################
@@ -1101,8 +1132,8 @@ class Wrapper:
 
         # アップロード
         res_put = self.api.session.put(s3_url, params=query_dict, data=data, headers={'content-type': content_type})
-        annofabapi.utils.log_error_response(logger, res_put)
-        annofabapi.utils.raise_for_status(res_put)
+        _log_error_response(logger, res_put)
+        _raise_for_status(res_put)
         return content["path"]
 
     #########################################
